Module: Hoe::Halostatue::Checklist
- Included in:
- Hoe::Halostatue
- Defined in:
- lib/hoe/halostatue/checklist.rb
Instance Attribute Summary collapse
-
#checklist ⇒ Object
An array of reminder questions that should be asked before a release, in the form,.
Instance Attribute Details
#checklist ⇒ Object
An array of reminder questions that should be asked before a release, in the form,
5 6 7 |
# File 'lib/hoe/halostatue/checklist.rb', line 5 def checklist @checklist end |