Module: Hoe::Halostatue::Gemspec
- Included in:
- Hoe::Halostatue
- Defined in:
- lib/hoe/halostatue/gemspec.rb
Instance Attribute Summary collapse
-
#reproducible_gemspec ⇒ Object
Whether a fixed date should be used for reproducible gemspec values.
Instance Attribute Details
#reproducible_gemspec ⇒ Object
Whether a fixed date should be used for reproducible gemspec values. This is ignored
if $SOURCE_DATE_EPOCH is set. Acceptable values are:
- `:default` or `true`: uses the RubyGems default source date epoch
- `:current`: uses the date stored in the most recent gemspec file
- `false`: sets the release date to the current date
- An epoch value, either as an Integer or a String
[default: :default]
13 14 15 |
# File 'lib/hoe/halostatue/gemspec.rb', line 13 def reproducible_gemspec @reproducible_gemspec end |