Module: Hoe::Halostatue::Git

Included in:
Hoe::Halostatue
Defined in:
lib/hoe/halostatue/git.rb

Instance Attribute Summary collapse

Instance Attribute Details

#git_release_tag_prefixObject

What do you want at the front of your release tags? [default: "v"]



8
9
10
# File 'lib/hoe/halostatue/git.rb', line 8

def git_release_tag_prefix
  @git_release_tag_prefix
end

#git_remotesObject

Which remotes do you want to push tags, etc. to? [default: %w[origin]]



12
13
14
# File 'lib/hoe/halostatue/git.rb', line 12

def git_remotes
  @git_remotes
end

#git_tag_enabledObject

Should git tags be created on release? [default: true]



15
16
17
# File 'lib/hoe/halostatue/git.rb', line 15

def git_tag_enabled
  @git_tag_enabled
end