Module: Hoe::Halostatue::Markdown
- Included in:
- Hoe::Halostatue
- Defined in:
- lib/hoe/halostatue/markdown.rb,
lib/hoe/halostatue/markdown/linkify.rb
Defined Under Namespace
Classes: Linkify
Instance Attribute Summary collapse
-
#markdown_linkify_files ⇒ Object
Specify which markdown files to linkify.
-
#markdown_linkify_style ⇒ Object
The style for producing links.
-
#markdown_linkify_uri_prefixes ⇒ Object
Controls whether shortened URIs for the current repository have prefixes added to them.
Instance Attribute Details
#markdown_linkify_files ⇒ Object
Specify which markdown files to linkify.
Should always be a list. May contain :default or {exclude: patterns} for special
handling.
:default ensures that all .md files in the manifest are included.
{exclude: patterns} excludes files matching any of the provided patterns (a glob
string, a regular expression, or a list of glob strings or regular expressions).
[default: [:default], any markdown files found in spec.files]
17 18 19 |
# File 'lib/hoe/halostatue/markdown.rb', line 17 def markdown_linkify_files @markdown_linkify_files end |
#markdown_linkify_style ⇒ Object
The style for producing links. The options are:
:reference, which will produce named reference links (e.g.,[#123][gh-issue-123]):inline, which produces inline links (e.g.,[#123](https://…))
Existing links will not be modified.
When using reference links, existing reference link definitions will not be moved, but new definitions will be appended to the end of the file.
28 29 30 |
# File 'lib/hoe/halostatue/markdown.rb', line 28 def markdown_linkify_style @markdown_linkify_style end |
#markdown_linkify_uri_prefixes ⇒ Object
Controls whether shortened URIs for the current repository have prefixes added to
them. This is either falsy (no prefixes added), true default prefixes are added, or
a map with one or more type (issue, pull, discussion) and the prefix to be
applied. The default prefixes (when true) are
{issue: 'issue', pull: 'pull', discussion: 'discussion'}.
Examples (assuming true):
[issue #123](https://github.com/cogswellcogs/sprocketkiller/issues/123
[pull #246](https://github.com/cogswellcogs/sprocketkiller/pull/246)
[discussion #369](https://github.com/cogswellcogs/sprocketkiller/discussions/369)
43 44 45 |
# File 'lib/hoe/halostatue/markdown.rb', line 43 def markdown_linkify_uri_prefixes @markdown_linkify_uri_prefixes end |